@@ -5,8 +5,8 @@
 
 /* Sendmail -- a sendmail compatible interface to ZMailer */
 
-#include <stdio.h>
 #include "hostenv.h"
+#include <stdio.h>
 #include <sysexits.h>
 #include <ctype.h>
 #include <pwd.h>
@@ -16,9 +16,9 @@
 # include FCNTL_H
 #endif
 #include <sys/file.h>
-#ifdef	USE_SYSLOG
+#ifdef	HAVE_SYSLOG
 #include <syslog.h>
-#endif	/* USE_SYSLOG */
+#endif	/* HAVE_SYSLOG */
 
 #define	SMTPSERVER	"smtpserver"
 #define	ROUTER		"router"
@@ -96,8 +96,12 @@ main(argc, argv)
 	configfile = pooption = NULL;
 	if (printq || aliases)
 		goto otherprog;
-	while ((c = getopt(argc, argv,"EJb:e:r:f:h:F:C:d:Oo:P:imnq:stvVx")) != EOF) {
+	while ((c = getopt(argc, argv,"B:EJb:e:r:f:h:F:C:d:Oo:P:imnq:stvVx")) != EOF) {
 		switch (c) {
+		case 'B':
+			/* Sendmail 8.7 compability:
+			   -B8BITMIME */
+			break;
 		case 'J': break; /* Sony NEWS OS  JIS-conversion option,
 				    ignore */
 		case 'E':
@@ -295,7 +299,7 @@ otherprog:
 		perror(path);
 		exit(EX_UNAVAILABLE);
 	} else {	/* ahh, normal, at last! */
-		SIGNAL_TYPE (*oldsig)();
+		RETSIGTYPE (*oldsig)();
 		SIGNAL_HANDLESAVE(SIGINT, SIG_IGN, oldsig);
 		if (oldsig != SIG_IGN)
 			SIGNAL_HANDLE(SIGINT, doabort);
@@ -339,12 +343,12 @@ otherprog:
 		  /* if we are setuid root, and not invoked by root,
 		     hardwire in the definition of from so the mailer
 		     will know */
-#ifdef	USE_FCHOWN
+#ifdef	HAVE_FCHOWN
 		  runasrootuser();
 		  if (uid != 0 && fchown(fileno(mfp), uid, -1) == 0)
 		    ;
 		  else
-#endif /* USE_FCHOWN */
+#endif /* HAVE_FCHOWN */
 		    if (from == NULL) {
 		      if (uid != 0 && (pwd = getpwuid(uid)) != NULL)
 			from = pwd->pw_name;
@@ -353,9 +357,9 @@ otherprog:
 		      else	/* could find with getpwnam */
 			from = "root";
 		    }
-#ifdef	USE_FCHOWN
+#ifdef	HAVE_FCHOWN
 		  runastrusteduser();
-#endif /* USE_FCHOWN */
+#endif /* HAVE_FCHOWN */
 		}
 
 		vfd = -1;
