@@ -35,10 +35,10 @@ rfc822tz(timep, ts, prettyname)
 		sign ? '+' : '-', offset / 60, offset % 60);
 	cp = zone + strlen(zone);
 
-#ifdef	HAVE_TMZONE
+#ifdef	HAVE_TM_ZONE
 	if (prettyname)
 	  sprintf(cp," (%s)",(*ts)->tm_zone);
-#else	/* !HAVE_TMZONE */
+#else	/* !HAVE_TM_ZONE */
 #ifdef HAVE_TZNAME
 	if (prettyname)
 	  sprintf(cp, " (%s)", tzname[(*ts)->tm_isdst]);
