@@ -21,14 +21,24 @@ getdtablesize()
         return(res.rlim_cur);
 }
 
-#else /* Brr... what ever... */
+#ifdef HAVE_SYSCONF
 
+#include <unistd.h>
+
+int
+getdtablesize()
+{
+	return sysconf(_SC_OPEN_MAX);
+}
+
+#else /* Brr... what ever... */
 int
 getdtablesize()
 {
 	return 256; 
 }
 #endif
+#endif
 #else
 static int dummy = 0;
 #endif
