@@ -46,7 +46,11 @@ static char sccsid[] = "@(#)syslog.c	5.28 (Berkeley) 6/27/90";
 #include <sys/file.h>
 #include "syslog.h"
 #include <sys/uio.h>
-#include <varargs.h>
+#ifdef HAVE_STDARG_H
+# include <stdarg.h>
+#else
+# include <varargs.h>
+#endif
 #include <stdio.h>
 
 #ifndef	_PATH_LOGNAME
@@ -85,22 +89,7 @@ xstrerror(e)
     return buff;
 }
 
-/* VARARGS0 */
-syslog(va_alist)
-    va_dcl
-{
-	int pri;
-	char *fmt;
-	va_list ap;
-
-	va_start(ap);
-	pri = va_arg(ap, int);
-	fmt = va_arg(ap, char*);
-	vsyslog(pri, fmt, ap);
-	va_end(ap);
-}
-
-vsyslog(pri, fmt, ap)
+void vsyslog(pri, fmt, ap)
 	int pri;
 	register char *fmt;
 	va_list ap;
@@ -193,6 +182,31 @@ vsyslog(pri, fmt, ap)
 	(void)close(fd);
 }
 
+
+#ifdef HAVE_STDARG_H
+void syslog(int pri, char *fmt, ...)
+#else
+/* VARARGS0 */
+void syslog(va_alist)
+    va_dcl
+#endif
+{
+	va_list ap;
+#ifdef HAVE_STDARG_H
+	va_start(ap,fmt);
+#else
+	int pri;
+	char *fmt;
+
+	va_start(ap);
+	pri = va_arg(ap, int);
+	fmt = va_arg(ap, char*);
+#endif
+	vsyslog(pri, fmt, ap);
+	va_end(ap);
+}
+
+
 static struct sockaddr SyslogAddr;	/* AF_UNIX address of local logger */
 /*
  * OPENLOG -- open system log
