@@ -30,11 +30,11 @@ extern int wait();
 # endif
 #endif
 
-#ifndef WIFEXITED
-# define WIFEXITED(s) (((s) >> 8) & 0377)
+#ifndef WEXITSTATUS
+# define WEXITSTATUS(s) (((s) >> 8) & 0377)
 #endif
-#ifndef WIFSIGNALED
-# define WIFSIGNALED(s) ((s) & 0177)
+#ifndef WSIGNALSTATUS
+# define WSIGNALSTATUS(s) ((s) & 0177)
 #endif
 
 
@@ -1050,14 +1050,14 @@ sh_wait(argc, argv)
 	}
 	if (pid < 0)		/* no more children */
 		return 0;
-	if (WIFSIGNALED(status) > 0) {
-		fprintf(stderr, "%s", strsignal(WIFSIGNALED(status)));
+	if (WSIGNALSTATUS(status) != 0) {
+		fprintf(stderr, "%s", strsignal(WSIGNALSTATUS(status)));
 		if (status&0200)
 			fprintf(stderr, CORE_DUMPED);
 		fprintf(stderr, "\n");
-		retcode = 0200 + WIFSIGNALED(status);
+		retcode = 0200 + WSIGNALSTATUS(status);
 	} else
-		retcode = WIFEXITED(status);
+		retcode = WEXITSTATUS(status);
 	return retcode;
 }
 
