@@ -887,9 +887,9 @@ runio(ioopp)
 					++errflag;
 					break;
 				}
-				unlink(ioop->name);
+				unlink((void*)ioop->name);
 				/* if the pipe already exists, don't bother */
-				if (mknod(ioop->name, S_IFIFO, 0) < 0) {
+				if (mknod((void*)ioop->name, S_IFIFO, 0) < 0) {
 					fprintf(stderr, "%s: %s %s\n", progname,
 							CANNOT_MKNOD,
 							ioop->name);
