@@ -90,9 +90,12 @@ int (*statfcn)() = stat;
  */
 
 int
-pathcmp(a, b)
-	register u_char **a, **b;
+pathcmp(ap, bp)
+     const void *ap, *bp;
 {
+	register const u_char **a = (const u_char **)ap;
+	register const u_char **b = (const u_char **)bp;
+
 	if (**a == **b)
 		return strcmp((char *)*a, (char *)*b);
 	return **a - **b;
