@@ -7,8 +7,8 @@
  * Trap script and signal management, and the builtin "trap" command.
  */
 
-#include <stdio.h>
 #include "hostenv.h"
+#include <stdio.h>
 #include <ctype.h>
 #include <sys/stat.h>
 #include "zmsignal.h"
@@ -71,7 +71,7 @@ int interrupted;		/* XX: we saw an interrupt */
  * stored in the orig_handler[] array.
  */
 
-SIGNAL_TYPE (*orig_handler[NSIG])();
+RETSIGTYPE (*orig_handler[NSIG])();
 
 /*
  * Indeed, that is what the trapsnap() function does.
