@@ -23,7 +23,7 @@
 #include "sh.h"
 
 
-extern SIGNAL_TYPE trap_handler();
+extern RETSIGTYPE trap_handler();
 extern char *optarg;
 extern char *strerror();
 extern int errno;
