@@ -817,7 +817,7 @@ db(dbname, key)
 		if (si.ttl > 0) {
 			dbip->cache->expiry = now + si.ttl;
 			if (D_db)
-				fprintf(stderr, " (ttl=%ld)\n", si.ttl);
+				fprintf(stderr, " (ttl=%d)\n", (int)si.ttl);
 		} else {
 			dbip->cache->expiry = 0;
 			if (D_db)
@@ -863,7 +863,7 @@ cacheflush(dbip)
 	int i;
 	struct conscell *ll;
 
-	if (dbip == NULL || dbip->cache_size == 0 | dbip->cache == NULL)
+	if (dbip == NULL || dbip->cache_size == 0 || dbip->cache == NULL)
 		return;
 
 	/* flush cache */
