@@ -8,7 +8,7 @@
 /* LINTLIBRARY */
 
 #include "mailer.h"
-#ifdef	USE_DBM
+#ifdef	HAVE_DBM_H
 
 #ifdef	NULL
 #undef	NULL
@@ -88,9 +88,9 @@ close_dbm(sip)
 		return;
 	if (inited == 0)
 		return;
-#ifdef	USE_DBMCLOSE
+#ifdef	HAVE_DBMCLOSE
 	dbmclose();
-#endif	/* USE_DBMCLOSE */
+#endif	/* HAVE_DBMCLOSE */
 	inited = 0;
 }
 
@@ -216,4 +216,4 @@ owner_dbm(sip, outfp)
 	fprintf(outfp, "%d\n", stbuf.st_uid);
 	fflush(outfp);
 }
-#endif	/* USE_DBM */
+#endif	/* HAVE_DBM_H */
