@@ -696,7 +696,7 @@ defer(e, why)
 	  sprintf(path, "../%s/%s.%s", DEFERREDDIR, e->e_file, why);
 	}
 	s = path;
-	while (s = strchr(s, ' ')) /* remap blanks to '-':es.. */
+	while ((s = strchr(s, ' '))) /* remap blanks to '-':es.. */
 	  *s = '-';
 	unlink(path);
 
@@ -1688,7 +1688,7 @@ sequencer(e, file)
 	fprintf(ofp, "%c%c%s\n",
 		_CF_MESSAGEID, _CFTAG_NORMAL, file);
 	fprintf(ofp, "%c%c%d\n",
-		_CF_BODYOFFSET, _CFTAG_NORMAL, e->e_msgOffset);
+		_CF_BODYOFFSET, _CFTAG_NORMAL, (int)(e->e_msgOffset));
 	if (envid != NULL)
 		fprintf(ofp, "%c%c%s\n",
 			_CF_DSNENVID, _CFTAG_NORMAL, envid);
@@ -1795,7 +1795,7 @@ sequencer(e, file)
 			/* print envelope sender address */
                         putc(_CF_ERRORADDR, ofp);
                         putc(_CFTAG_NORMAL, ofp);
-                        fprintf(ofp,"%s\n",rwp->errto);
+                        fprintf(ofp,"%s\n",(char*)(rwp->errto));
 		}
 
 		for (nsp = rwp->down; nsp != NULL; nsp = nsp->next) {
