@@ -4,7 +4,7 @@
  */
 /*
  *	Lots of modifications (new guts, more or less..) by
- *	Matti Aarnio <mea@nic.funet.fi>  (copyright) 1992-1995
+ *	Matti Aarnio <mea@nic.funet.fi>  (copyright) 1992-1996
  */
 
 /* stdout and stderr end up in qlogdir/progname when scheduler is a daemon */
@@ -31,3 +31,6 @@ int	nobody = -2;
 
 /* directory scanning interval in seconds */
 int	sweepinterval = 10;
+
+/* At most 10 new childs per second -- The 'R'-option can be used to increase this */
+int	forkrate_limit = 10;
