@@ -28,16 +28,16 @@ static int qpchannel();
 static int qphost();
 extern char *saytime();
 
-#ifdef	USE_TIMEVAL
+#ifdef	HAVE_UTIMES
 #include <sys/time.h>
-#else	/* !USE_TIMEVAL */
+#else	/* !HAVE_UTIMES */
 /*#include <unistd.h> */
 /* some systems have utimbuf defined in unistd.h, some don't... */
 struct utimbuf {
 	time_t	actime;
 	time_t	modtime;
 };
-#endif	/* USE_TIMEVAL */
+#endif	/* !HAVE_UTIMES */
 
 static FILE *qpfp;
 static char qpch;
@@ -49,11 +49,11 @@ void
 qprint(fd)
 	int fd;
 {
-#ifdef	USE_TIMEVAL
+#ifdef	HAVE_UTIMES
 	struct timeval tvp[2];
-#else	/* !USE_TIMEVAL */
+#else	/* !HAVE_UTIMES */
 	struct utimbuf tvp;
-#endif	/* USE_TIMEVAL */
+#endif	/* !HAVE_UTIMES */
 
 	/*
 	 * The O_NDELAY flag is needed so we don't block
@@ -105,14 +105,14 @@ qprint(fd)
 	/* XX: I suppose we don't really need to do this if we use TCP. */
 	if (rendezvous != NULL) {
 	  time_t now = mytime(NULL) - 1;
-#ifdef	USE_TIMEVAL
+#ifdef	HAVE_UTIMES
 	  tvp[0].tv_sec = tvp[1].tv_sec = now;
 	  tvp[0].tv_usec = tvp[1].tv_usec = 0;
 	  utimes(rendezvous, tvp);
-#else	/* !USE_TIMEVAL */
+#else	/* !HAVE_UTIMES */
 	  tvp.actime = tvp.modtime = now;
 	  utime(rendezvous, &tvp);
-#endif	/* USE_TIMEVAL */
+#endif	/* !HAVE_UTIMES */
 	}
 }
 
