@@ -1004,9 +1004,11 @@ struct offsort {
 
 static char *bcp;
 
-static int bcfcn(a, b) struct offsort *a, *b;
+static int bcfcn(a, b)
+     const void *a, *b;
 {
-	return cistrcmp(bcp + a->offset, bcp + b->offset);
+	const struct offsort *aa = a, *bb = b;
+	return cistrcmp(bcp + aa->offset, bcp + bb->offset);
 }
 
 
