@@ -1,7 +1,7 @@
 /* Small pieces for scanning forward on a buffer of RFC-821/822 compliant
    addresses */
 
-/* (c) Matti Aarnio 1993 <mea@nic.funet.fi> */
+/* (c) Matti Aarnio 1993-1996 <mea@nic.funet.fi> */
 
 /* All these routines scan over the lexical elements they are after, and
    if successfull, return pointer just AFTER such element.
@@ -39,6 +39,8 @@ static const char *no_input       = "No input";
 	(a?CHAR_ALPHA:0)|(b?CHAR_ALNUM:0)|(c?CHAR_SPECL:0)|	\
 	(d?CHAR_DIGIT:0)|(e?CHAR_C:0)|(f?CHAR_X:0)|(g?CHAR_Q:0)
 
+/* Could use 'unsigned char' here, but the Alpha machines dislike
+   anything smaller than int (32 bit) */
 static int char_array[] = {
 		/*        /----------------- CHAR_ALPHA
 			  | /--------------- CHAR_ALNUM
@@ -174,7 +176,7 @@ static int char_array[] = {
 /* 123: `{'    */ CHR_ENT(0,0,0,0,1,1,1,0,0),
 /* 124: `|'    */ CHR_ENT(0,0,0,0,1,1,1,0,0),
 /* 125: `}'    */ CHR_ENT(0,0,0,0,1,1,1,0,0),
-/* 126: `~'    */ CHR_ENT(0,0,0,0,0,1,1,0,0),
+/* 126: `~'    */ CHR_ENT(0,0,0,0,1,1,1,0,0),
 /* 127: `DEL'  */ CHR_ENT(0,0,0,0,0,1,1,0,0),
 /* 128: `\200' */ CHR_ENT(0,0,0,0,0,0,0,0,0),
 /* 129: `\201' */ CHR_ENT(0,0,0,0,0,0,0,0,0),
@@ -429,27 +431,28 @@ int *allnump;	/* Return a flag about all-numeric field.. */
 
 	/* The first test should be  is_821_alpha(), as per RFC821
 	   we should accept only A-Z,a-Z in the begining, but
-	   3COM spoiled that... Grr...				*/
+	   3COM spoiled that... Grumble...			*/
+	/* So now we allow chars:  0-9, A-Z, a-z, and '-'  for valid at
+	   the domain name segment -- but '-' is not ok at the begin.   */
+	/* To note futher; the underscore is not allowed at the DNS,
+	   and thus it should not be allowed at email addresses either. */
+	/* Our caller will do deeper analysis, wether or not ALL of the
+	   input was numeric:  foo@12.34.56.78   If yes, special error
+	   message is reported. For that purpose we count '-' as an alpha */
 
-	if (!is_821_alnum(*p)) {
+	c = *p;
+	if (!is_821_alnum(c)) {
 	  rfc821_error_ptr = p;
 	  rfc821_error = bad_name;
-	  return s; /* Don't advace, leave! */
+	  return s; /* Don't advance, leave! */
 	}
-	has_alpha |= is_821_alpha(*p);
-	c = *(p++);
-	while (is_821_alnum(*p) || (*p == '-') || (*p == '_')) {
-	  has_alpha |= is_821_alpha(*p);
-	  c = *(p++);
+	while (is_821_alnum(c) || (c == '-')) {
+	  has_alpha |= (is_821_alpha(c) || c == '-');
+	  c = *(++p);
 	}
 
 	*allnump &= !has_alpha;
 
-	if (!is_821_alnum(c) || (strict && !has_alpha)) {
-	  rfc821_error_ptr = p-1;
-	  rfc821_error = bad_name;
-	  return s; /* Bad <name>, don't advance */
-	}
 	return p;	/* Name ok, return advanced pointer */
 }
 
@@ -751,6 +754,14 @@ int strict;
 	  /* Report whatever part2() reports as an error */
 	  return s;
 	}
+	if (*q== ' ' || *q == '\t') {
+	  /* Sometimes sending systems have:  <foo@foo   >, painfull.. */
+	  for (q = q+1; (*p == ' ' || *p == '\t'); )  ++p;
+	  /* Ok, copy down the rest of the input, and thus save the day..
+	     Purist would just report an error, but lets be lenient, when
+	     it is fairly easy, and painless to do.. */
+	  if (*p == '>') strcpy(q, p);
+	}
 	if (*q != '>') {
 	  rfc821_error = "Missing \">\" at end";
 	  if (*q)
