@@ -1,10 +1,10 @@
-#include <stdio.h>
 #include "hostenv.h"
+#include <stdio.h>
 
 #include <sys/types.h>
 #include <sys/fcntl.h>
 
-#ifdef	USE_STATVFS
+#ifdef	HAVE_STATVFS
 # include <sys/statvfs.h>
 # define FSTATFS fstatvfs
 # define STATFSTYPE struct statvfs
