@@ -34,14 +34,14 @@ char *dfltform[] = {
 
 char *progname;
 
-extern void warning();
 extern char *optarg;
 extern int optind;
 extern int emptyline();
-extern void prversion(), process();
+extern void prversion();
+extern void process();
+
 extern char *strrchr();
 extern char *strchr();
-extern char *buildboundary();
 
 extern char *mydomain();
 
