@@ -117,18 +117,17 @@ struct conshell *envarlist = NULL;
 #endif
 int	D_alloc = 0;
 
-extern void warning(), report();
 extern char *optarg;
 extern int optind;
-extern int emptyline();
-extern void prversion(), process();
-extern int hold();
+extern void prversion();
+extern void process();
+extern int  hold();
 extern time_t time();
 extern char **environ;
 
 extern char *strchr(), *strrchr();
 extern struct hostent *gethostbyname(), *gethostbyaddr();
-extern int ranny();
+extern int   ranny();
 
 #ifdef	lint
 #undef	putc
