@@ -537,7 +537,11 @@ ctlopen(file, channel, host, exitflagp, selectaddr, matchrouter)
 	  return NULL;
 	}
 
+#ifdef USE_ALLOCA
+	mfpath = alloca((u_int)5+sizeof(QUEUEDIR)+strlen(d.msgfile));
+#else
 	mfpath = emalloc((u_int)5+sizeof(QUEUEDIR)+strlen(d.msgfile));
+#endif
 	sprintf(mfpath, "../%s/%s", QUEUEDIR, d.msgfile);
 	if ((d.msgfd = open(mfpath, O_RDONLY, 0)) < 0) {
 	  int e = errno;
@@ -547,7 +551,9 @@ ctlopen(file, channel, host, exitflagp, selectaddr, matchrouter)
 	  }
 	  errno = e;
 	  warning("Cannot open message file \"%s\"! (%m)", mfpath);
+#ifndef USE_ALLOCA
 	  free(mfpath);
+#endif
 	  ctlclose(&d);
 	  return NULL;
 	}
@@ -561,7 +567,9 @@ ctlopen(file, channel, host, exitflagp, selectaddr, matchrouter)
 		       "Message file is not a regular file!");
 	  }
 	  warning("Cannot open message file \"%s\"! (%m)", mfpath);
+#ifndef USE_ALLOCA
 	  free(mfpath);
+#endif
 	  ctlclose(&d);
 	  close(d.msgfd);
 	  return NULL;
@@ -573,7 +581,9 @@ ctlopen(file, channel, host, exitflagp, selectaddr, matchrouter)
 	if ((long)d.let_buffer == -1L) {
 	  warning("Out of MMAP() memory! Tried to map in (r/o) %d bytes (%m)",
 		  stbuf.st_size);
+#ifndef USE_ALLOCA
 	  free(mfpath);
+#endif
 	  ctlclose(&d);
 	  close(d.msgfd);
 	  return NULL;
@@ -581,6 +591,10 @@ ctlopen(file, channel, host, exitflagp, selectaddr, matchrouter)
 	d.let_end    = d.let_buffer + stbuf.st_size;
 #endif
 
+#ifndef USE_ALLOCA
+	  free(mfpath);
+#endif
+
 	d.msgsizeestimate = stbuf.st_size + largest_headersize;
 	/* A nice fudge factor, usually this is enough..                 */
 	/* Add 3% for CRLFs.. -- assume average line length of 35 chars. */
