@@ -12,7 +12,7 @@
 #include "malloc.h"
 
 #if	defined(HAVE_RESOLVER)
-#include "netdb.h"
+#include <netdb.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 #endif	/* HAVE_RESOLVER */
@@ -24,8 +24,8 @@
 #endif	/* TRY_AGAIN */
 #ifdef	BIND
 #undef NOERROR /* Solaris  <sys/socket.h>  has  NOERROR too.. */
-#include "arpa/nameser.h"
-#include "resolv.h"
+#include <arpa/nameser.h>
+#include <resolv.h>
 
 #ifndef	BIND_VER
 #ifdef	GETLONG
