@@ -119,7 +119,6 @@ struct utimbuf {
 #include <netdb.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
-#include <net/if.h>
 #endif	/* HAVE_SOCKET */
 
 #ifdef HAVE_PROTOCOLS_RWHOD_H
@@ -264,7 +263,6 @@ extern int  qptext_check __((struct rcpt *rp));
 extern void hp_init();
 extern char **hp_getaddr();
 extern int errno;
-extern void warning();
 extern char *strchr(), *strrchr();
 extern int  lstat(); /* remaps to  stat() if USE_LSTAT is not defined.. */
 extern FILE *fdopen();
@@ -276,6 +274,10 @@ struct conshell *envarlist = NULL;
 extern int stickymem;	/* for strsave() */
 int	D_alloc = 0;
 
+#if defined(HAVE_SOCKET) && defined(HAVE_PROTOCOLS_RWHOD_H)
+static int readrwho __((void));
+#endif
+
 static void sig_alrm(sig)
 int sig;
 {
@@ -1852,7 +1854,7 @@ biff(hostname, username, offset)
 
 
 #if defined(HAVE_SOCKET) && defined(HAVE_PROTOCOLS_RWHOD_H)
-int
+static int
 readrwho()
 {
 	struct whod wd;
@@ -1874,7 +1876,7 @@ readrwho()
 	struct spblk *spl;
 	
 	if (spt_users == NULL)
-	  return;
+	  return 0;
 	now = time(NULL);
 	if (chdir(RWHODIR) || (dirp = opendir(".")) == NULL ) {
 	  /* BE SILENT -- failing RBIFF is no fault! */
@@ -1884,7 +1886,7 @@ readrwho()
 	     exit(EX_OSFILE);
 	   */
 	}
-	while (dp = readdir(dirp)) {
+	while ((dp = readdir(dirp))) {
 	  if (dp->d_ino == 0
 	      || strncmp(dp->d_name, "whod.", 5)
 	      || (f = open(dp->d_name, 0)) < 0 )
