@@ -71,11 +71,10 @@ extern RETSIGTYPE wantout();
 extern univptr_t emalloc();
 extern univptr_t erealloc();
 #endif
-extern void warning();
 extern char *optarg;
 extern int optind;
-extern int getmyuucpname(), emptyline();
-extern struct maildesc *readsmcf();
+extern int getmyuucpname();
+extern struct maildesc *readsmcf __((char *file, char *mailer));
 extern void prversion();
 extern void process __((struct ctldesc *dp, struct maildesc *mp, FILE *verboselog));
 extern void deliver __((struct ctldesc *dp, struct maildesc *mp, struct rcpt *startrp, struct rcpt *endrp, FILE *verboselog));
