@@ -6,26 +6,27 @@
    is strlen(string)+1, not strlen(string) !
 */
 
+#include "hostenv.h"
 #include <stdio.h>
 #include <ctype.h>
 #include <sys/types.h>
 #include <fcntl.h>
-#include "hostenv.h"
-#ifdef USE_NDBM
+#ifdef HAVE_NDBM
 #include <ndbm.h>
 #else
-#ifdef USE_GDBM
+#ifdef HAVE_GDBM
 #include <gdbm.h>
 #else
-	 error:error:Only NDBM and GDBM supported! (NDBM primarily)
+	error:error:Only NDBM and GDBM supported! (NDBM primarily)
 #endif
 #endif
 
 #define PROG "makendbm"
 
-extern int errno;
-extern char *sys_errlist[];
-extern int sys_nerr;
+#include <errno.h>	/* This (usually) defines the following 3.. */
+     /* extern int errno;
+	extern char *sys_errlist[];
+	extern int sys_nerr; */
 
 extern char *strchr();
 
@@ -38,7 +39,7 @@ int errno;
 {
   fprintf(stderr,"Usage: %s database.name [infilename|-]\n",prog);
   fprintf(stderr,"  If no infilename is defined, database.name is assumed.\n");
-#ifdef USE_NDBM
+#ifdef HAVE_NDBM
   fprintf(stderr,"  (NDBM appends  .pag, and .dir  into actual db file names..)\n");
 #else /* GDBM.. */
   fprintf(stderr,"  (GDBM DOES NOT append .pag, nor .dir  into actual db file names..)\n");
@@ -57,7 +58,7 @@ char *argv[];
 {
   char *dbasename = NULL;
   FILE *infile = NULL;
-#ifdef USE_NDBM
+#ifdef HAVE_NDBM
   DBM *dbmfile;
 #else
   GDBM_FILE dbmfile;
@@ -77,7 +78,7 @@ char *argv[];
 
   if (infile == NULL) usage(argv[0],"bad infile",errno);
 
-#ifdef USE_NDBM
+#ifdef HAVE_NDBM
   dbmfile = dbm_open(dbasename, O_RDWR|O_CREAT|O_TRUNC, 0644);
 #else
   /* Play loose .. don't do syncs while writing */
@@ -97,7 +98,7 @@ char *argv[];
 void
 create_dbase(infile,dbmfile)
 FILE *infile;
-#ifdef USE_NDBM
+#ifdef HAVE_NDBM
 DBM *dbmfile;
 #else
 GDBM_FILE dbmfile;
@@ -138,7 +139,7 @@ GDBM_FILE dbmfile;
 	  dat.dptr  = s;
 	  dat.dsize = strlen(s)+1;
 
-#ifdef USE_NDBM
+#ifdef HAVE_NDBM
 	  if (dbm_store(dbmfile, key, dat, DBM_INSERT) != 0)
 #else
 	  if (gdbm_store(dbmfile, key, dat, GDBM_INSERT) != 0)
